@@ -1,9 +1,10 @@
 from __future__ import division, absolute_import, print_function
 
 import os
+import pytest
 
-from numpy.testing import run_module_suite, assert_, dec
-import util
+from numpy.testing import assert_
+from . import util
 
 
 def _path(*a):
@@ -17,7 +18,7 @@ class TestAssumedShapeSumExample(util.F2PyTest):
                _path('src', 'assumed_shape', 'foo_mod.f90'),
                ]
 
-    @dec.slow
+    @pytest.mark.slow
     def test_all(self):
         r = self.module.fsum([1, 2])
         assert_(r == 3, repr(r))
@@ -30,6 +31,3 @@ class TestAssumedShapeSumExample(util.F2PyTest):
         assert_(r == 3, repr(r))
         r = self.module.mod.fsum([1, 2])
         assert_(r == 3, repr(r))
-
-if __name__ == "__main__":
-    run_module_suite()
